summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xbuild/buildcheck.sh8
-rw-r--r--configure.in3
2 files changed, 5 insertions, 6 deletions
diff --git a/configure.in b/configure.in
index cd2cf069f..0d16d0e31 100644
--- a/configure.in
+++ b/configure.in
@@ -139,9 +139,8 @@ AC_CHECK_PROG(ASCPP, cpp, cpp)
AC_CHECK_TOOL(AR, ar, ar)
dnl Various OS checks that apparently set required flags
-AC_AIX
+AC_USE_SYSTEM_EXTENSIONS
AC_ISC_POSIX
-AC_MINIX
APR_EBCDIC
diff --git a/build/buildcheck.sh b/build/buildcheck.sh
index 62fe931ae..637ef140a 100755
--- a/build/buildcheck.sh
+++ b/build/buildcheck.sh
@@ -14,18 +14,18 @@ py_version=`python -c 'import sys; print sys.version' 2>&1|sed 's/ .*//;q'`
echo "buildconf: python version $py_version (ok)"
fi
# autoconf 2.50 or newer
ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
if test -z "$ac_version"; then
echo "buildconf: autoconf not found."
-echo " You need autoconf version 2.50 or newer installed"
+echo " You need autoconf version 2.60 or newer installed"
echo " to build APR from SVN."
exit 1
fi
IFS=.; set $ac_version; IFS=' '
-if test "$1" = "2" -a "$2" -lt "50" || test "$1" -lt "2"; then
+if test "$1" = "2" -a "$2" -lt "60" || test "$1" -lt "2"; then
echo "buildconf: autoconf version $ac_version found."
-echo " You need autoconf version 2.50 or newer installed"
+echo " You need autoconf version 2.60 or newer installed"
echo " to build APR from SVN."
exit 1
else
@@ -14,18 +14,18 @@ py_version=`python -c 'import sys; print sys.version' 2>&1|sed 's/ .*//;q'`
echo "buildconf: python version $py_version (ok)"
fi
-# autoconf 2.50 or newer
+# autoconf 2.60 or newer
ac_version=`${AUTOCONF:-autoconf} --version 2>/dev/null|sed -e 's/^[^0-9]*//;s/[a-z]* *$//;q'`
if test -z "$ac_version"; then